import { Injectable } from '@angular/core';
import { NatsService } from 'app/core/nats/services/nats.service';
import * as nats from 'nats.ws';

import {
  CheckUsernameForDuplicationRequest,
  CheckUsernameForDuplicationResponse,
} from 'app/modules/protobuf/c2se/common/identity_pb';
import { SUBJECT_CHECK_USERNAME_FOR_DUPLICATION } from 'app/modules/protobuf/c2se/backend/identity_pb';

@Injectable({
  providedIn: 'root',
})
export class IdentityService {
  /**
   * Constructor
   */
  constructor(private __natsService: NatsService) {}

  // -----------------------------------------------------------------------------------------------------
  // @ Accessors
  // -----------------------------------------------------------------------------------------------------

  // -----------------------------------------------------------------------------------------------------
  // @ Public methods
  // -----------------------------------------------------------------------------------------------------

  checkUsernameForDuplication(username: string): Promise<boolean> {
    return new Promise<boolean>((resolve, reject) => {
      let req = new CheckUsernameForDuplicationRequest();
      req.setUsername(username);

      this.__natsService
        .request<CheckUsernameForDuplicationResponse.Result>(
          SUBJECT_CHECK_USERNAME_FOR_DUPLICATION,
          req.serializeBinary(),
          CheckUsernameForDuplicationResponse.deserializeBinary
        )
        .then((result) => {
          console.log('success', result, result.getDuplicated());
        })
        .catch((e) => {
          console.log('failed', e);
        });
    });
  }
}
